Struct kbnf_syntax::node::FinalAlternation
source · pub struct FinalAlternation {
pub concatenations: Vec<FinalNode>,
}Fields
concatenations: Vec<FinalNode>Trait Implementations
sourceimpl Clone for FinalAlternation
impl Clone for FinalAlternation
sourcefn clone(&self) -> FinalAlternation
fn clone(&self) -> FinalAlternation
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for FinalAlternation
impl Debug for FinalAlternation
sourceimpl Hash for FinalAlternation
impl Hash for FinalAlternation
sourceimpl Ord for FinalAlternation
impl Ord for FinalAlternation
sourcefn cmp(&self, other: &FinalAlternation) -> Ordering
fn cmp(&self, other: &FinalAlternation) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for FinalAlternation
impl PartialEq for FinalAlternation
sourcefn eq(&self, other: &FinalAlternation) -> bool
fn eq(&self, other: &FinalAlternation) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for FinalAlternation
impl PartialOrd for FinalAlternation
sourcefn partial_cmp(&self, other: &FinalAlternation) -> Option<Ordering>
fn partial_cmp(&self, other: &FinalAlternation) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Eq for FinalAlternation
impl StructuralPartialEq for FinalAlternation